==> dde-launchpad_1.99.15.tar.xz: BUILD/shell-launcher-applet/translations/org.deepin.ds.dock.launcherapplet_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Fixar no topo</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation>Mover para o topo</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Remover dos favoritos</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Adicionar aos favoritos</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Remover da área de trabalho</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Enviar para área de trabalho</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Remover do dock</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Fixar no dock</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Remover da inicialização</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Adicionar à inicialização</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Usar proxy</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Desativar escala de exibição</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="33"/>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="62"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="109"/>
        <source>Full-screen Mode</source>
        <translation>Modo tela cheia</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation>Usado frequentemente</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="254"/>
        <source>Window Mode</source>
        <translation>Modo janela</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Comunicação</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Imagem</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="32"/>
        <source>Games</source>
        <translation>Jogos</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Produtividade</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Leitura</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Desenvolvimento</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Outros</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="400"/>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="412"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="426"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>Instalado recentemente</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Todos os aplicativos</translation>
    </message>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="557"/>
        <location filename="../../qml/windowed/SearchResultView.qml" line="102"/>
        <source>No search results</source>
        <translation>Nenhum resultado encontrado</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Classificação livre</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Classificar por categoria</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Classificar por nome</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation>Modo de classificação</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation>Computador</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation>Imagens</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation>Área de Trabalho</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation>Central de Controle</translation>
    </message>
</context>
<context>
    <name>launcheritem</name>
    <message>
        <location filename="../package/launcheritem.qml" line="111"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="113"/>
        <source>Chat</source>
        <translation>Bate papo</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="115"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="117"/>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="119"/>
        <source>Graphics</source>
        <translation>Gráficos</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="121"/>
        <source>Games</source>
        <translation>Jogos</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="123"/>
        <source>Office</source>
        <translation>Escritório</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="125"/>
        <source>Reading</source>
        <translation>Leitura</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="127"/>
        <source>Development</source>
        <translation>Desenvolvimento</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="129"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="131"/>
        <source>Others</source>
        <translation>Outros</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="162"/>
        <source>launchpad</source>
        <translation>Plataforma de lançamento</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="309"/>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="321"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="335"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
</TS>

==> dde-launchpad_2.0.1.tar.xz: BUILD/shell-launcher-applet/translations/org.deepin.ds.dock.launcherapplet_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Fixar no topo</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation>Mover para o topo</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Remover dos favoritos</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Adicionar aos favoritos</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Remover da área de trabalho</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Enviar para área de trabalho</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Remover do dock</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Fixar no dock</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Remover da inicialização</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Adicionar à inicialização</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Usar proxy</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Desativar escala de exibição</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="33"/>
        <source>Power</source>
        <translation>Energia</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="62"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="109"/>
        <source>Full-screen Mode</source>
        <translation>Modo tela cheia</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation>Usado frequentemente</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="254"/>
        <source>Window Mode</source>
        <translation>Modo janela</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Comunicação</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Imagem</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="32"/>
        <source>Games</source>
        <translation>Jogos</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Produtividade</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Leitura</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Desenvolvimento</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Outros</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="400"/>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>Desinstalar &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="412"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="426"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>Instalado recentemente</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Todos os aplicativos</translation>
    </message>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="557"/>
        <location filename="../../qml/windowed/SearchResultView.qml" line="102"/>
        <source>No search results</source>
        <translation>Nenhum resultado encontrado</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Classificação livre</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Classificar por categoria</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Classificar por nome</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation>Modo de classificação</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation>Computador</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation>Imagens</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation>Área de Trabalho</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation>Central de Controle</translation>
    </message>
</context>
<context>
    <name>launcheritem</name>
    <message>
        <location filename="../package/launcheritem.qml" line="111"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="113"/>
        <source>Chat</source>
        <translation>Bate papo</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="115"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="117"/>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="119"/>
        <source>Graphics</source>
        <translation>Gráficos</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="121"/>
        <source>Games</source>
        <translation>Jogos</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="123"/>
        <source>Office</source>
        <translation>Escritório</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="125"/>
        <source>Reading</source>
        <translation>Leitura</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="127"/>
        <source>Development</source>
        <translation>Desenvolvimento</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="129"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="131"/>
        <source>Others</source>
        <translation>Outros</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="162"/>
        <source>launchpad</source>
        <translation>Plataforma de lançamento</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="309"/>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>Desinstalar &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="321"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="335"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
</context>
</TS>
